pub enum SecretsSubCommand {
Create(SecretsCreateSubCmdArgs),
Copy(SecretsCopySubCmdArgs),
Edit(SecretsEditSubCmdArgs),
EnvFile(SecretsEnvFileSubCmdArgs),
List(SecretsListSubCmdArgs),
Push(SecretsPushSubCmdArgs),
View(SecretsViewSubCmdArgs),
}Variants
Create(SecretsCreateSubCmdArgs)
Create an empty secret (metadata only, no version).
Copy(SecretsCopySubCmdArgs)
Copy a secret value from one secret ID to another in the same region.
Edit(SecretsEditSubCmdArgs)
Fetch latest version of a secret and open the default editor to edit it.
EnvFile(SecretsEnvFileSubCmdArgs)
Fetch the secrets and write an environment file to a specified path.
List(SecretsListSubCmdArgs)
List all versions of a secret.
Push(SecretsPushSubCmdArgs)
Push new key-value pairs to existing secrets.
View(SecretsViewSubCmdArgs)
Show the latest version of a secret.