pub struct Environment<M = ImplicitIndex> {
pub name: EnvironmentName,
pub index: EnvironmentIndex,
/* private fields */
}Fields
name: EnvironmentNameindex: EnvironmentIndexImplementations
Sourceimpl<M> Environment<M>
impl<M> Environment<M>
Sourceimpl Environment<ImplicitIndex>
impl Environment<ImplicitIndex>
Sourcepub fn into_explicit(self) -> Environment<ExplicitIndex>
pub fn into_explicit(self) -> Environment<ExplicitIndex>
Turn an non explicit environment into an explicit one. An explicit environment will always append the index number to its display names. Whereas a non-explicit one (default) only append the index if it is different than 1.
Sourceimpl Environment<ExplicitIndex>
impl Environment<ExplicitIndex>
pub fn into_implicit(self) -> Environment<ImplicitIndex>
Sourceimpl<M: IndexStyle> Environment<M>
impl<M: IndexStyle> Environment<M>
pub fn long(&self) -> String
pub fn medium(&self) -> String
pub fn short(&self) -> String
Sourcepub fn get_dotenv_filename(&self) -> String
pub fn get_dotenv_filename(&self) -> String
Backward-compatible helper for env-specific base filename.
Sourcepub fn get_dotenv_secrets_filename(&self) -> String
pub fn get_dotenv_secrets_filename(&self) -> String
Backward-compatible helper for env-specific secrets filename.
Sourcepub fn get_env_files(&self) -> Vec<String>
pub fn get_env_files(&self) -> Vec<String>
All possible .env files for this environment, by family. Order matters: later files override earlier ones.
Sourcepub fn merge_env_files(&self) -> Result<PathBuf>
pub fn merge_env_files(&self) -> Result<PathBuf>
Merge all the .env files of the environment with all variable expanded